_me = frm_timezone.prototype;
function frm_timezone(){};

_me.__constructor = async function(aHandler) {
	var me = this;
	this._dockable(false);
	this._resizable(false);
	this._closable(false);
	this._modal(true);
	this._title('SETTINGS::TIMEZONE');

	await this._draw('frm_timezone','main');
	this._size(430,'auto',true);
	this.tz._value(normalizeTimezone(GWOthers.getItem('CALENDAR_SETTINGS', 'timezone')));

	this.x_btn_ok._onclick = async function() {
		dataSet.add('tmp_storage','',dataSet.get('storage','',true));
		GWOthers.set('CALENDAR_SETTINGS',{timezone:me.tz._value()},'storage');
		if (await WMStorage.set({'resources':dataSet.get('storage')},'storage','',[me,'__saveItemsHandler']) == 2){
			dataSet.remove('tmp_storage');
			me.x_btn_cancel._onclick();
		}
	};

	this.x_btn_cancel._onclick = function() {
		me._destruct();
		executeCallbackFunction(aHandler);
	};

	this.tz._obeyEvent('show', [function(_, data) {
		var zIndex = +getComputedStyle(me._main).zIndex;
		if (zIndex) {
			data.owner.block._zIndex(zIndex + 1);
		}
	}]);
};

_me.__saveItemsHandler = function(bOK)
{
	//Přijal server náš dotaz?
	if (!bOK)
		dataSet.add('storage','',dataSet.get('tmp_storage'));

	dataSet.remove('tmp_storage');
	this.x_btn_cancel._onclick();
};